.. -*- coding: utf-8 -*-
   
=========
 Credits
=========

The **MDAnalysisData** package is modelled after `sklearn.datasets
<http://scikit-learn.org/stable/modules/classes.html#module-sklearn.datasets>`_
and uses some of its code (under the `BSD 3-clause license
<https://github.com/scikit-learn/scikit-learn/blob/master/COPYING>`_)
and alchemtest_.

No data are included in this package; please see the `DESCR` attribute
for each data set for authorship, citation, and license information
for the data.

**MDAnalysisData** is made available under the `New BSD 3-clause
license <https://github.com/MDAnalysis/MDAnalysisData/blob/master/LICENSE>`_.

.. _alchemtest: https://alchemtest.readthedocs.io   
